<?php
/*
  $Id: contrib_tracker.php,v 1.8.0 2014/07/07 00:00:00 $

  Designed for: osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Released under the GNU General Public License
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/* ///////////////////////////////////////////////////////
 * Notes on Using Dates in this contribution
 * ///////////////////////////////////////////////////////
 * 
 * 'note_created' -- Date Added to Store 
 *    DESCRIPTION: This field is used for the date the current contribution was added to the store.
 *    USAGE: This data field is exclusively maintained and updated by the user for their reference.
 * 
 * 'last_update' -- Current Installed Version Date (formerly: Last integrated into store)
 *    DESCRIPTION: This field is used as the date of the Last, or Current, contribution date 
 *                 currently installed in the shop.
 *    USAGE: This data field is exclusively maintained and updated by the user for their reference.
 * 
 * 'contr_last_modified' -- Lastest at addons.oscommerce.com (formerly: Last official update)
 *    DESCRIPTION: This field is used by the code to maintain the date of the latest uploaded 
 *                 version at addons.oscommerce.com
 *    USAGE: This data field is exclusively maintained and updated by the code, and should always 
 *           reflect the date of the latest upload at addons.oscommerce.com
 * 
 * 'status_reference_date' -- Status Reference Date
 *    DESCRIPTION: This field is used by the code to compare to the dates retrieved from the 
 *                 contribution page at addons.oscommerce.com and the RSS feed.  This data field is
 *                 manipulated to allow the user to decide whether the latest official update at
 *                 addons.oscommerce.com is useful to their installation. If a new official release is 
 *                 detected, the user can reset the display to indicate the contribution is up-to-date. 
 *                 The code changes this field to the latest official release date for future comparison. 
 *                 Maintaining this "reference date" allows all the other dates to always reflect their intended uses.
 *    USAGE: - This data field is manipulated by the code. 
 *           - When a contribution is added, this field is set to the 'last_update' entered by the user 
 *             and the entry has a contribution ID entered by the user.
 *           - The user has the ability to reset this field to the 'last_update' date in the edit page.
 *           - If an update check determines a new release exists by comparing the new date to this one, 
 *             the status is changed to red (0) (update is available).
 *           - If the user determines the new release is not applicable to their installation, they click the 
 *             green status icon and this date is set to the latest release date from 'contr_last_modified' 
 *             and the status is reset to green (1). If they later decide to return the status to red (0),
 *             clicking the red status icon will set this field to the 'last_update' date.
 * 
 * ////////////////////////////////////////////////////// */


require('includes/application_top.php');

require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_CONTRIB_TRACKER);
require(DIR_WS_FUNCTIONS . 'contrib_tracker.php');

// include configurer and check for updates.
require(DIR_WS_CLASSES.substr(FILENAME_CONTRIB_TRACKER,0,-4).'_configurer.php');
$conf = new configurer(CONFIGURER_PROCESS_UPDATES);
/*if ($conf->db_version_outofdate()) {
  tep_redirect(tep_href_link('configurer.php','conf='.substr(FILENAME_CONTRIB_TRACKER,0,-4)));
}*/

// web URLs constants used.
define ('CONTRIB_TRACKER_XML_URL',          'http://feedproxy.feedburner.com/osCommerce_Contributions');
define ('CONTRIB_TRACKER_ADDONS_URL',       'http://addons.oscommerce.com/');
define ('CONTRIB_TRACKER_CONTRIBS_URL',     'http://addons.oscommerce.com/info/');
define ('CONTRIB_TRACKER_OLD_CONTRIBS_URL', 'http://www.oscommerce.com/community/contributions,');
define ('CONTRIB_TRACKER_SUPPORT_URL',      'http://forums.oscommerce.com/index.php?showtopic=');

// CONTRIB_TRACKER_MYSQL_DATE_FORMAT is the date format MySQL stores and understands as a valid date.
define ('CONTRIB_TRACKER_MYSQL_DATE_FORMAT','%Y-%m-%d %H:%M:%S');
// CONTRIB_TRACKER_MYSQL_EMPTY_DATE is the date MySQL stores for a zero or empty date.
define ('CONTRIB_TRACKER_MYSQL_EMPTY_DATE','0000-00-00 00:00:00');
// CONTRIB_TRACKER_DISPLAY_FORMAT is the date format for displaying on Contrib Tracker's main page.
define ('CONTRIB_TRACKER_DISPLAY_FORMAT','%Y-%m-%d'); // you can use the US standard of mm-dd-yyyy ('%m-%d-%Y') here if you wish.
// CONTRIB_TRACKER_UPDATE_FORMAT is the date format that is filled into the contrib info update form that you then edit.
define ('CONTRIB_TRACKER_UPDATE_FORMAT','%Y-%m-%d'); // use either '%Y-%m-%d' or '%d-%m-%Y', as the US standard '%m-%d-%Y' will confuse the poor PHP strtotime() function

// initialize
$contrib_info = array();
$action = tep_db_prepare_input($HTTP_GET_VARS['action']);
$max_display_results = 30;   // can be site search default if you wish:  MAX_DISPLAY_SEARCH_RESULTS;

// scrub
$sID = tep_db_prepare_input($HTTP_GET_VARS['sID']);
$page = tep_db_prepare_input($HTTP_GET_VARS['page']);
$sort = tep_db_prepare_input($HTTP_GET_VARS['sort']);
$search = tep_db_prepare_input($HTTP_GET_VARS['search']);

$dadded = isset($HTTP_GET_VARS['dadded']);
$dcurrent = isset($HTTP_GET_VARS['dcurrent']);
$dlatest = isset($HTTP_GET_VARS['dlatest']);
$showrss = isset($HTTP_GET_VARS['showrss']);

// if you wish to have this code check the RSS feed every time 
// you open the Contribution Tracker, uncomment the next line.
//$showrss = true; 


// get rss feed and update contributions if showrss is checked.
if (empty($action) && $showrss) {
	$articlelist = tep_process_oscommerce_rss_feed();
}

if (tep_not_null($action)) {
  switch ($action) {
	  
    // Setflag icon pressed 
    case 'setflag': /* Checked, working */
	  $id = tep_db_prepare_input($HTTP_GET_VARS['id']);
	  $flag = tep_db_prepare_input($HTTP_GET_VARS['flag']);
	  $set_date = tep_db_prepare_input($HTTP_GET_VARS['set_date']);

	  tep_set_contrib_query_status($id, $flag, $set_date);
      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'id', 'flag', 'set_date'))));
      break;

    // Save Date entered in Last Manual Contrib Check: line at top of page
    case 'updatecheck': /* Checked, working */
	  $lastcheck = tep_db_prepare_input($HTTP_POST_VARS['lastcheck']);
	
      $contrib_query = "update " . TABLE_CONFIGURATION . " set configuration_value = '" . tep_db_input($lastcheck) . "', last_modified = now() where configuration_key = 'LAST_CONFIG_CHECK'";    
    
      if (tep_db_query($contrib_query)){
        $messageStack->add_session(MESSAGE_UPDATECHECK_SUCCESS, 'success');
      }else{
        $messageStack->add_session(MESSAGE_UPDATECHECK_ERROR, 'error');
      } 

      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action'))));
      break;
    
	// Insert button clicked, Insert clicked to save new contrib
    case 'insert': /* Checked, working */
	
	  $contrib_id_new = (int)tep_db_prepare_input($HTTP_POST_VARS['contrib_id_new']);   // this contributions ID at osCommerce
      $old_status = tep_db_prepare_input($HTTP_POST_VARS['old_status']);
      $status = tep_db_prepare_input($HTTP_POST_VARS['status']);
      $last_update = tep_db_prepare_input($HTTP_POST_VARS['last_update']);
      $note_created = tep_db_prepare_input($HTTP_POST_VARS['note_created']);
      $contrib_link = tep_db_prepare_input($HTTP_POST_VARS['contrib_link_new']);
      $contrib_name = tep_db_prepare_input($HTTP_POST_VARS['contrib_name_new']);
      $contrib_vers = tep_db_prepare_input($HTTP_POST_VARS['contrib_vers']);
      $contrib_link_support = tep_db_prepare_input($HTTP_POST_VARS['contrib_link_support']);
      $config_comments = tep_db_prepare_input($HTTP_POST_VARS['config_comments']);
	  $date_added = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;
	  $date_updated = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;
	  $last_osc_update = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;
	  $status_reference_date = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;

      if (isset($HTTP_POST_VARS['today_date'])){
        $date_updated = date("Y-m-d H:M:S");
      } else {
        $date_updated = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, $last_update);
      }
      
      if (isset($HTTP_POST_VARS['today_date2'])){
        $date_added = date("Y-m-d H:M:S");
      } else {
        $date_added = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, $note_created);
      }
  
	  // set status_reference_date to date of Currently Installed contribution "for reference"
	  if (!empty($contrib_id_new)) {
		$status_reference_date = $date_updated;
	  }
		
	  // if they just entered the topic ID in the field, build the support link
	  if (is_numeric($contrib_link_support)) {
		  $contrib_link_support = CONTRIB_TRACKER_SUPPORT_URL . $contrib_link_support;
	  }

      $contrib_link = old_to_new_url($contrib_link);
	  
	  if (empty($contrib_link) && is_numeric($contrib_id_new) && $contrib_id_new > 0) {
		// link empty, build it from contrib ID
        $contrib_link = CONTRIB_TRACKER_CONTRIBS_URL . $contrib_id_new;
      } elseif (!empty($contrib_link) && !(is_numeric($contrib_id_new) && $contrib_id_new > 0))  {
	    // get ID from contrib link entered
	    $contrib_link_id = get_contrib_id($contrib_link);
		
	    // if the id is empty and the contrib link ID isn't, update the contrib ID
	    if ( (!is_numeric($contrib_id_new) || (is_numeric($contrib_id_new) && $contrib_id_new < 1)) && is_numeric($contrib_link_id) && $contrib_link_id > 0 ) {
	      $contrib_id_new = $contrib_link_id;
	    }
	  }
      
	  // if the id is still empty set warning
	  if (!is_numeric($contrib_id_new) || (is_numeric($contrib_id_new) && $contrib_id_new == 0)) {
	    $contrib_id_new = 0;
	    $messageStack->add_session(MESSAGE_WARNING_CONTRIB_ID_NOT_FOUND, 'success');
	  }
		
	  //check whether contrib is already in database
	  $record_found = false;
      if (!empty($contrib_id_new)) {
        $contrib_query = tep_db_query("select contrib_osc_id from " . TABLE_CONTRIB_TRACKER . " where contrib_osc_id = '" . $contrib_id_new . "'");
        $record_found = (tep_db_num_rows($contrib_query) !== 0);
      }

      if (!$record_found){
     
		// get contribs info if available
		if(!empty($contrib_id_new)) {
		  $contrib_info = contrib_check($contrib_id_new);
		}
		
		// set name retrieved if user didn't input one
		if (empty($contrib_name) && !empty($contrib_info['contrib_name'])) {
		  $contrib_name = $contrib_info['contrib_name'];
		}
	
		// if latest update date is empty at this point zero it.
		if (!empty($contrib_info['last_osc_update'])) {
		  $last_osc_update = $contrib_info['last_osc_update'];
		}
		
		// set flag to red if need be
		if (strtotime($date_updated) < strtotime($last_osc_update)) {
		  $status='0';
		} else {
		  $status='1';
		}

		// Add support link if user didn't provide one and one exists in the contrib info
		if (empty($contrib_link_support) && !empty($contrib_info['contrib_support_topic'])) {
		  $contrib_link_support = CONTRIB_TRACKER_SUPPORT_URL . $contrib_info['contrib_support_topic'];
		}

		$contrib_query = "insert into " . TABLE_CONTRIB_TRACKER . " (contrib_osc_id, contrib_name, contrib_link, contrib_support, config_comments, note_created, contr_last_modified, status, last_update, status_reference_date, contrib_vers) values ('" . (int)$contrib_id_new . "', '" . tep_db_input($contrib_name) . "', '" . tep_db_input($contrib_link) . "', '" . tep_db_input($contrib_link_support) . "', '" . tep_db_input($config_comments) . "', '" .  tep_db_input($date_added) . "', '" .  tep_db_input($last_osc_update) . "', '" .  tep_db_input($status) . "', '" . tep_db_input($date_updated) . "', '" . tep_db_input($status_reference_date) . "', '" . tep_db_input($contrib_vers) . "' )";
		if ( tep_db_query($contrib_query) ){
		  $messageStack->add_session(MESSAGE_INSERT_SUCCESS, 'success');
		} else {
		  $messageStack->add_session(MESSAGE_INSERT_ERROR, 'error');
		}
		
      } else {
          $messageStack->add_session(MESSAGE_INSERT_DUPLICATE, 'error');
      }
      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action'))));
      break;
      
    // contribution was edited and then saved
    case 'update': /* Checked, working */
	
      $contr_id = tep_db_prepare_input($HTTP_POST_VARS['contr_id']);  // this contribution's ID in the contrib_tracker table.
	  $contrib_id_new = (int)tep_db_prepare_input($HTTP_POST_VARS['contrib_id_new']);   // this contributions ID at osCommerce
      $old_status = tep_db_prepare_input($HTTP_POST_VARS['old_status']);
      $status = tep_db_prepare_input($HTTP_POST_VARS['status']);
      $last_update = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, tep_db_prepare_input($HTTP_POST_VARS['last_update']));
      $note_created = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, tep_db_prepare_input($HTTP_POST_VARS['note_created']));
      $last_modified = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, tep_db_prepare_input($HTTP_POST_VARS['last_modified']));
      $contrib_link = tep_db_prepare_input($HTTP_POST_VARS['contrib_link_new']);
      $contrib_name = tep_db_prepare_input($HTTP_POST_VARS['contrib_name_new']);
      $contrib_vers = tep_db_prepare_input($HTTP_POST_VARS['contrib_vers']);
      $contrib_link_support = tep_db_prepare_input($HTTP_POST_VARS['contrib_link_support']);
      $config_comments = tep_db_prepare_input($HTTP_POST_VARS['config_comments']);
	  $date_added = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;
	  $date_updated = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;
	  
	  // if Today's Date is checked, set Current Installed Version date to today's date
	  if (isset($HTTP_POST_VARS['today_date'])) {
        $date_updated = date("Y-m-d H:M:S");
      } else {
        $date_updated = $last_update;
      }

	  // if Today's Date 2 is checked, set Date Added to Store to today's date
	  if (isset($HTTP_POST_VARS['today_date2'])) {
        $date_added = date("Y-m-d H:M:S");
      } else{
        $date_added = $note_created;
      }
	  
	  // handle status reference date
	  if (($status == '0' && $old_status == '1') || isset($HTTP_POST_VARS['reset_ref_date_to_current'])) {
        // set status reference date if switching from green to red status or checkbox selected
		$ref_date = $date_updated;
      } elseif ($status == '1' && $old_status == '0') {
        // set to contr_last_modified date passed from update form
		$ref_date = $last_modified;
      }
	  
	  // if they just entered the topic ID in the field, build the support link
	  if (is_numeric($contrib_link_support)) {
		$contrib_link_support = CONTRIB_TRACKER_SUPPORT_URL . $contrib_link_support;
	  }

      // convert old contrib links to new ones
      $contrib_link = old_to_new_url($contrib_link);
      
	  if (empty($contrib_link) && is_numeric($contrib_id_new) && $contrib_id_new > 0) {
		// link empty, build it from contrib ID
        $contrib_link = CONTRIB_TRACKER_CONTRIBS_URL . $contrib_id_new;
      } elseif (!empty($contrib_link) && !(is_numeric($contrib_id_new) && $contrib_id_new > 0))  {
	    // get ID from contrib link entered
	    $contrib_link_id = get_contrib_id($contrib_link);
		
	    // if the id is empty and the contrib link ID isn't, update the contrib ID
	    if ( (!is_numeric($contrib_id_new) || (is_numeric($contrib_id_new) && $contrib_id_new < 1)) && is_numeric($contrib_link_id) && $contrib_link_id > 0 ) {
	      $contrib_id_new = $contrib_link_id;
	    }
	  }
	  
	  // since we're doing an update, update contrib ID if link ID is different as amethod of 
	  // being able to change the contrib ID that is not editable in the update page
	  if (is_numeric($contrib_link_id) && $contrib_link_id > 0 && $contrib_id_new != $contrib_link_id) {
	    $contrib_id_new = $contrib_link_id;
	  }
      
	  // if the id is still empty set to zero
	  if (!is_numeric($contrib_id_new)) {
	    $contrib_id_new = 0;
	  }

      // if the name or support link is empty try to get them
      if (!empty($contrib_id_new) && (empty($contrib_name) || empty($contrib_link_support))) {
        $contrib_info = contrib_check($contrib_id_new);

		// set name retrieved if user didn't input one
		if (empty($contrib_name) && !empty($contrib_info['contrib_name'])) {
		  $contrib_name = $contrib_info['contrib_name'];
		}
	
		// Add support link if user didn't provide one and one exists in the contrib info
		if (empty($contrib_link_support) && !empty($contrib_info['contrib_support_topic'])) {
		  $contrib_link_support = CONTRIB_TRACKER_SUPPORT_URL . $contrib_info['contrib_support_topic'];
		}

      }

      $contrib_query = "update " .TABLE_CONTRIB_TRACKER . " set status =  '" . tep_db_input($status) . "', contrib_osc_id =  '" . tep_db_input($contrib_id_new) . "', contrib_name =  '" . tep_db_input($contrib_name) . "', contrib_link =  '" . tep_db_input($contrib_link) . "', contrib_support = '" . tep_db_input($contrib_link_support) . "', config_comments = '" . tep_db_input($config_comments) . "', last_update = '" . tep_db_input($date_updated) . "', note_created = '" . tep_db_input($date_added) . "'" . (!empty($ref_date) ? ", status_reference_date = '".$ref_date."'" : '' ) . ", contrib_vers = '" . tep_db_input($contrib_vers) . "' where contr_id = '" . (int)$contr_id . "'";

      if ( tep_db_query($contrib_query) ){
        $messageStack->add_session(MESSAGE_UPDATE_SUCCESS, 'success');
      }else{
        $messageStack->add_session(MESSAGE_UPDATE_SUCCESS, 'error');
      }
      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID')) . 'sID=' . $contr_id));
      break;
      
    // Contrib ID typed into Quick Add OSC ID: field on upper right of page
	case 'quick_insert': /* Checked, working */
	  $contrib_quick_insert = tep_db_prepare_input($HTTP_POST_VARS['contrib_quick_insert']);
	  
      if (is_numeric($contrib_quick_insert)){
        $contrib_name = '';
		$contrib_support_link = '';
        $date_added = date("Y-m-d H:M:S");
		$date_updated = date("Y-m-d H:M:S");
		$last_osc_update = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;
		$status_reference_date = CONTRIB_TRACKER_MYSQL_EMPTY_DATE;

        //check whether contrib is already in database
        $contrib_query = tep_db_query("select contrib_osc_id from " . TABLE_CONTRIB_TRACKER . " where contrib_osc_id = '" . tep_db_input($contrib_quick_insert) . "'");

        if (tep_db_num_rows($contrib_query) == 0) {

          //the get contrib info
          if ($contrib_info = contrib_check($contrib_quick_insert)) {
			  //Version cannot be automatically determined, set to nothing
			  $newvers='';
			  //set flag to green
			  $status='1';
	
			  if (!empty($contrib_info['contrib_name'])) {
				$contrib_name = $contrib_info['contrib_name'];
			  }
			  
			  if (!empty($contrib_info['contrib_support_topic'])) {
				$contrib_support_link = CONTRIB_TRACKER_SUPPORT_URL . $contrib_info['contrib_support_topic'];
			  }
			  
			  // if the latest update date for the contribution is found, use that for the Current Installed Version Date 
			  if (!empty($contrib_info['last_osc_update'])) {
				$date_updated = $contrib_info['last_osc_update'];
			  }
	
			  // if the latest update date for the contribution is found and there is an osC ID, use that for the rest of the dates
			  if (!empty($contrib_info['last_osc_update']) && !empty($contrib_quick_insert)) {
				$last_osc_update = $contrib_info['last_osc_update'];
		        $status_reference_date = $contrib_info['last_osc_update'];
			  }
	
			  $contrib_query = "insert into " . TABLE_CONTRIB_TRACKER . " (contrib_osc_id, contrib_name, contrib_link, contrib_support, config_comments, note_created, contr_last_modified, status, last_update, status_reference_date, contrib_vers) values ('" . tep_db_input($contrib_quick_insert) . "', '" . tep_db_input($contrib_name) . "', '" . tep_db_input(CONTRIB_TRACKER_CONTRIBS_URL . $contrib_quick_insert) . "', '" . tep_db_input($contrib_support_link) . "', '', '" .  tep_db_input($date_added) . "', '" . tep_db_input($last_osc_update) . "', '" . tep_db_input($status) . "', '" . tep_db_input($date_updated) . "', '" . tep_db_input($status_reference_date) . "', '" . tep_db_input($newvers) . "' )";
			  if (tep_db_query($contrib_query) ) {
				$messageStack->add_session(MESSAGE_INSERT_SUCCESS, 'success');
			  } else {
				$messageStack->add_session(MESSAGE_INSERT_ERROR, 'error');
			  }
			  $sID = tep_db_insert_id();
			  
          } else {
			$messageStack->add_session(sprintf(MESSAGE_ERROR_GETTING_CONTRIB_INFO,CONTRIB_TRACKER_CONTRIBS_URL.$contrib_quick_insert), 'error');
          }

		} else {
			$messageStack->add_session(MESSAGE_INSERT_DUPLICATE, 'error');
		}
        tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')).($sID?'sID='.$sID:'')));
      }
      break;

	// Delete clicked, then Confirm Delete clicked
	case 'deleteconfirm': /* Checked, working */
      $contrib_query = "delete from " . TABLE_CONTRIB_TRACKER. " where contr_id = '" . tep_db_input($sID) . "'";
      if ( tep_db_query($contrib_query) ){
        $messageStack->add_session(MESSAGE_DELETE_SUCCESS, 'success');
      }else{
        $messageStack->add_session(MESSAGE_DELETE_ERROR, 'error');
      }
      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID'))));
      break;
      
    // Manual Update icon pressed on list line
	case 'manualcheck': /* Checked, working */
	  $oscID = tep_db_prepare_input($HTTP_GET_VARS['oscID']);
	  
	  //the get contrib info
	  if ($contrib_info = contrib_check($oscID)) {
		  //update latest update date regardless
		  tep_db_query("UPDATE " . TABLE_CONTRIB_TRACKER . " SET contr_last_modified = '" . tep_db_input($contrib_info['last_osc_update']) . "' WHERE contrib_osc_id = '" . tep_db_input($oscID) . "'");
		  //if the date is newer then the installed contrib date database entry, set the flag
		  $update_query = "UPDATE " . TABLE_CONTRIB_TRACKER . " SET status ='0' WHERE contrib_osc_id = '" . tep_db_input($oscID) . "' and status_reference_date < '" . tep_db_input($contrib_info['last_osc_update']) . "'";

		  if ( tep_db_query($update_query) ){
			$messageStack->add_session(MESSAGE_UPDATE_SUCCESS, 'success');
		  }else{
			$messageStack->add_session(MESSAGE_UPDATE_ERROR, 'error');
		  }
	  } else {
		$messageStack->add_session(sprintf(MESSAGE_ERROR_GETTING_CONTRIB_INFO,CONTRIB_TRACKER_CONTRIBS_URL.$oscID), 'error');
	  }
      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'oscID'))));
      break;
	  
    case 'manualcheckall':
      $manual_checkall_query = tep_db_query("select contr_id, contrib_osc_id, contrib_name from " . TABLE_CONTRIB_TRACKER . " order by contrib_osc_id");
      if (tep_db_num_rows($manual_checkall_query) == 0) {
        $messageStack->add_session(MESSAGE_MANUALALL_NONE_ERROR, 'error');
      } else {
        while ($contrib_db_track = tep_db_fetch_array($manual_checkall_query)) {
		  if (!empty($contrib_db_track['contrib_osc_id'])) {
			  $contrib_site_info = contrib_check($contrib_db_track['contrib_osc_id']);
			  //update latest update date regardless
			  tep_db_query("UPDATE " . TABLE_CONTRIB_TRACKER . " SET contr_last_modified = '" . tep_db_input($contrib_site_info['last_osc_update']) . "' WHERE contrib_osc_id = '" . tep_db_input($contrib_db_track['contrib_osc_id']) . "'");
			  //if the date is newer then the installed contrib date database entry, set the flag
			  $update_query = "UPDATE " . TABLE_CONTRIB_TRACKER . " SET status ='0' WHERE contrib_osc_id = '" . tep_db_input($contrib_db_track['contrib_osc_id']) . "' and status_reference_date < '" . tep_db_input($contrib_site_info['last_osc_update']) . "'";
			  if ( !tep_db_query($update_query) ){
				//$messageStack->add_session(MESSAGE_MANUALALL_SUCCESS, 'success');
			  //}else{
				$messageStack->add_session(MESSAGE_MANUALALL_ERROR.$contrib_db_track['contrib_name'], 'error');
			  }
		  }
        }
      }
      tep_redirect(tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action'))));
      break;
  }
}

?><!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
    <title><?php echo TITLE; ?></title>
    <link rel="stylesheet" type="text/css" href="includes/stylesheet.css">
    <link rel="stylesheet" type="text/css" href="includes/javascript/spiffyCal/spiffyCal_v2_1.css">
    <script language="javascript" src="includes/javascript/spiffyCal/spiffyCal_v2_1.js"></script>
    <script language="javascript" type="text/javascript" src="includes/general.js"></script>
    <script language="javascript" type="text/javascript"> 
    if (typeof(toggleDivBlock) !== 'function') {
      var toggleDivBlock = function(id) {
        if (document.getElementById) {
          itm = document.getElementById(id);
        } else if (document.all){
          itm = document.all[id];
        } else if (document.layers){
          itm = document.layers[id];
        }

        if (itm) {
          if (itm.style.display != "none") {
            itm.style.display = "none";
          } else {
            itm.style.display = "block";
          }
        }
      } 
    }
    </script>
<?php
// set sub title
      if ( $action == 'readonly') $HEADING_SUB_TITLE = HEADING_SUB_TITLE_READONLY;
      if ( $action == 'delete') $HEADING_SUB_TITLE = HEADING_SUB_TITLE_DELETE;
      if ( $action == 'update') $HEADING_SUB_TITLE = HEADING_SUB_TITLE_EDIT;
      if ( $action == 'edit') $HEADING_SUB_TITLE = HEADING_SUB_TITLE_EDIT;
      if ( $action == 'new') $HEADING_SUB_TITLE = HEADING_SUB_TITLE_INSERT;
      if ( $action == 'setflag') $HEADING_SUB_TITLE = HEADING_SUB_TITLE_SETFLAG;
      if ( $action == '') $HEADING_SUB_TITLE = HEADING_SUB_TITLE;
?>
  <style>
  .go { vertical-align: baseline; font-size: 10px; height: 20px; margin-left: 2px; }

  input[type=text] {
     height: 20px;
  }
  input[type=checkbox] {
    padding: 0;
    margin:0;
    position: relative;
    top: 3px;
    *overflow: hidden;
  }
  input[type=checkbox] + label {
    padding-left: 4px;
    padding-right: 14px;
  }
  .headertable .cal-TextBox,
  .headertable .headerfields,
  .inputtable .cal-TextBox,
  .inputtable .shortinputfields,
  .inputtable .inputfields {
	  font-size: 11px;
	  font-family: Verdana, Arial, sans-serif;
	  border: #999 1px solid;
	  background-color: #FFF;
	  margin: 0 2px;
  }
  .headertable .cal-TextBox,
  .headertable .headerfields,
  .inputtable .shortinputfields,
  .inputtable .cal-TextBox {
	  width: 140px;
  }
  .inputtable .inputfields {
	  width: 400px;
  }
  .inputtable textarea {
	  width: 500px;
  }
  .so-BtnLink img {
	 display: inline-block;
	 position: relative;
	 top: -2px;
	 z-index: 0;
  }
  table.cal-Table {
	 display: inline-block;
	 position: relative;
	 z-index: 100;
  }
  </style>
  </head>
  <body bgcolor="#FFFFFF" onLoad="SetFocus();">
<?php if ($action == 'editlastcheck') { ?>
    <script language="javascript" type="text/javascript"> 
	var selectCheckDate = function() {
	  document.forms['lastcheck'].elements['lastcheck'].focus();
	  document.forms['lastcheck'].elements['lastcheck'].select();
    }

    var oldonload = window.onload;
    if (typeof window.onload !== 'function') {
      window.onload = selectCheckDate;
    } else {
      window.onload = function() {
        if (oldonload) {
          oldonload();
        }
        selectCheckDate();
      }
    }
	</script>
<?php } ?>
    
    <div id="spiffycalendar" class="text"></div>

<!-- header //-->
  <?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->
<!-- body //-->
<table border="0" width="100%" cellspacing="2" cellpadding="2">
  <tr>
    <td width="<?php echo BOX_WIDTH; ?>" valign="top"><table border="0" width="<?php echo BOX_WIDTH; ?>" cellspacing="1" cellpadding="1" class="columnLeft">
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
    </table></td>
<!-- body_text //-->
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="2" cellpadding="2">
      <tr>
        <td width="100%" valign="top">
          <table border="0" width="100%" cellspacing="0" cellpadding="0">
            <tr>
              <td class="pageHeading"><?php echo HEADING_TITLE; ?>
                <?php echo '<a href="'.CONTRIB_TRACKER_ADDONS_URL.'" target="_blank">' . tep_image(DIR_WS_IMAGES . 'html_badge.gif', HEADING_CONTRIB_HTML_SUPPORT_SITE, '80', '15') . '</a>&nbsp;&nbsp; <a href="'. CONTRIB_TRACKER_XML_URL .'" target="_blank">' . tep_image(DIR_WS_IMAGES . 'rss_badge.gif', HEADING_CONTRIB_RSS_SUPPORT_SITE, '80', '15') . '</a>'; ?> &nbsp;
                <br /><font class="smallText"><?php echo $HEADING_SUB_TITLE; ?></font>
              </td>
              <td class="pageHeading" align="right"><?php echo tep_draw_separator('pixel_trans.gif', 10, 1); ?></td>
<?php 
  // show header options only if not doing actions
  if ($action != 'new' && $action != 'edit' && $action != 'readonly') {
    if (htmlspecialchars($search) == ''){
      $searchquery = ''; 
    } else { 
      $searchquery = htmlspecialchars($search) ;
    }
?>
              <td align="right">
                <table border="0" width="100%" cellspacing="0" cellpadding="1" class="headertable">
                  <tr> 
                    <td class="smallText" align="right"> 
                      <?php echo tep_draw_form('search', FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')), 'get');
                            echo HEADING_TITLE_CONTRIBSEARCH . ' ' . tep_draw_input_field('search', '', 'placeholder="- enter search query -" class="headerfields"'); 
							echo tep_draw_input_field('search', 'Go', 'class="go"', false, 'submit'); ?>
                      </form>
                    </td>
                  </tr>
                  <tr>
                    <td class="smallText" align="right">
                      <?php echo tep_draw_form('quick_insert', FILENAME_CONTRIB_TRACKER, 'action=quick_insert', 'post');
                            echo TEXT_QUICKOSC_ID .' '. TEXT_ID_QUICK_NEW . ' ' . tep_draw_input_field('contrib_quick_insert', '', 'placeholder="- enter contrib ID -" class="headerfields"'); 
							echo tep_draw_input_field('search', 'Go', 'class="go"', false, 'submit'); ?>
                      </form>
                    </td>
                  </tr>

                  <tr>
    <?php if ($action == 'editlastcheck') { ?>
 <!--  SHOW THE TITLE AND A FIELD TO ENTER A NEW DATE -->
                    <td class="smallText" align="right">
					  <?php echo tep_draw_form('lastcheck', FILENAME_CONTRIB_TRACKER,'action=updatecheck&amp;id=' . $admin_quer['contr_id'] . '&amp;page=' . $page .  '&amp;sID=' . $sID, 'post');
                            echo HEADING_LAST_CHECK . ' ';  //tep_draw_input_field('lastcheck', tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, LAST_CONFIG_CHECK), 'id="lastcheck"' );
                            ?><script language="javascript">
								 var manualLastCheck = new ctlSpiffyCalendarBox("manualLastCheck", "lastcheck", "lastcheck", "", "<?php echo tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, LAST_CONFIG_CHECK); ?>"); /* "class_instance_name", "form_name", "field_name", "button_name", "default_date", "button_mode" */
								 manualLastCheck.focusClick=true;
								 manualLastCheck.hideButton=true;
							     manualLastCheck.writeControl();
							     manualLastCheck.dateFormat="yyyy-MM-dd";
                                 manualLastCheck.x=getOffsetLeft(document.forms['lastcheck'].elements['lastcheck']) - 80;
                                 manualLastCheck.y=getOffsetTop(document.forms['lastcheck'].elements['lastcheck']) + 22;
                              </script><?php
							echo tep_draw_input_field('search', 'Go', 'class="go"', false, 'submit'); ?>
                      </form>
                    </td>
                    
    <?php } else { ?>

<!-- // JUST SHOW THE TITLE AND DATE FOR LAST MANUAL UPDATE AS A LINK -->
                    <td class="smallText" align="right"> 
                      <?php echo ' <a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'id')) . 'action=editlastcheck&amp;id=' . $admin_quer['contr_id'], 'NONSSL') . '">' . HEADING_LAST_CHECK . ' ' . tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, LAST_CONFIG_CHECK, 'none') .'</a>'; ?>
                    </td>
    <?php } ?>
                  </tr>
                </table>
              </td>
<?php 
  } else {
	  // spacer for continuity
       echo '              <td>' . tep_image(DIR_WS_IMAGES . 'pixel_trans.gif', '', 10, 58) . '</td>';
  }
?>            
            </tr>
<?php

  // start: insert/update form
  if ( ($action == 'new') || ($action == 'edit') ) {
    if ($action == 'new') {
      $form_action = 'insert';
    } else if ($action == 'edit') {
      $form_action = 'update';
    }
                
// UPDATE A CONTRIBUTION ENTRY
    if ( ($action == 'edit') && ($sID) ) {
      $product_query = tep_db_query("select contr_id, contrib_osc_id, contrib_name, contrib_link, contrib_support, status, config_comments, last_update, contr_last_modified, status_reference_date, note_created, contrib_vers from " . TABLE_CONTRIB_TRACKER . " where contr_id = '" . $sID . "'");
      $product = tep_db_fetch_array($product_query);
      $sInfo = new objectInfo($product);
    } else {
      $sInfo = new objectInfo(array());
      $contr_array = array();
    }
?>

            <tr>
              <td colspan="3">
                <?php echo tep_draw_form('new_contr', FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'info', 'sID')) . 'action=' . $form_action); ?>
                <?php /*?><form name="new_contr" <?php echo 'action="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'info', 'sID')) . 'action=' . $form_action, 'NONSSL') . '"'; ?> method="post"><?php */?>
				<?php if ($form_action == 'update') echo tep_draw_hidden_field('contr_id', $sID) ; ?>
                  <br />
                  <table border="0" cellspacing="0" cellpadding="2" class="inputtable">
        
          <?php if ($action == 'new'){ ?>
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_OSC_ID; ?></td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('contrib_id_new', $sInfo->contrib_osc_id, 'size=10 maxlength=10 class="shortinputfields"').' '. TEXT_ID_NOTE_NEW; ?></td>
                    </tr>
          <?php }else if ($action == 'edit'){ ?>        
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_OSC_ID; ?> <?php echo tep_draw_hidden_field('contrib_id_new', $sInfo->contrib_osc_id);?></td>
                      <td class="dataTableContent"><?php echo $sInfo-> contrib_osc_id; ?></td>
                    </tr>
          <?php } ?>
        
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_NAME_VERSION; ?></td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('contrib_name_new', $sInfo->contrib_name, 'size=50 maxlength=255 class="inputfields"').' &nbsp;'. TEXT_NAME_NOTE_NEW; ?></td>
                    </tr>
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_INFO_HTML; ?></td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('contrib_link_new', $sInfo->contrib_link, 'size=50 maxlength=255 class="inputfields"').' &nbsp;'.TEXT_OSC_URL; ?></td>
                    </tr>
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_INFO_SUPPORT; ?></td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('contrib_link_support', $sInfo->contrib_support, 'size=50 maxlength=255 class="inputfields"').' &nbsp;'.TEXT_OSC_SUPPORT; ?></td>
                    </tr>
          <!-- // insert version number field -->
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_VERSION_NUMBER; ?>&nbsp;</td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('contrib_vers', $sInfo->contrib_vers, 'size=50 maxlength=30 class="shortinputfields"').' &nbsp;'. TEXT_VERSION_NOTE_NEW; ?></td>
                    </tr>

                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_INFO_DATE_ADDED; ?>&nbsp;</td>
                      <td class="dataTableContent"><script language="javascript">
													 var addedToStoreDate = new ctlSpiffyCalendarBox("addedToStoreDate", "new_contr", "note_created", "atsd", "<?php echo tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, $sInfo->note_created, ''); ?>"); /* "class_instance_name", "form_name", "field_name", "button_name", "default_date", "button_mode" */
								                     addedToStoreDate.focusClick=true;
													 addedToStoreDate.writeControl();
													 addedToStoreDate.displayLeft=true;
													 addedToStoreDate.dateFormat="yyyy-MM-dd";
													</script><?php // echo tep_draw_input_field('note_created', tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, $sInfo->note_created, ''), 'id="note_created" size=50 maxlength=30 placeholder="'.TEXT_PLACEHOLDER.'"'); 
					                                                  echo ' &nbsp; ' .  tep_draw_checkbox_field('today_date2', 'y','',''). ' '. TEXT_TODAY_DATE.' &nbsp;'. TEXT_ADD_DATE_NEW; ?></td>
                    </tr>
                    
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_INFO_TO_REMEMBER; ?>&nbsp;</td>
                      <td class="dataTableContent"><script language="javascript">
													 var installedVersionDate = new ctlSpiffyCalendarBox("installedVersionDate", "new_contr", "last_update", "ivd", "<?php echo tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, $sInfo->last_update, ''); ?>"); /* "class_instance_name", "form_name", "field_name", "button_name", "default_date", "button_mode" */
								                     installedVersionDate.focusClick=true;
													 installedVersionDate.writeControl();
													 installedVersionDate.displayLeft=true;
													 installedVersionDate.dateFormat="yyyy-MM-dd";
													</script><?php // echo tep_draw_input_field('last_update', tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, $sInfo->last_update, ''), 'id="last_update" size=50 maxlength=30 placeholder="'.TEXT_PLACEHOLDER.'"');
					                                                  echo ' &nbsp; ' . tep_draw_checkbox_field('today_date', 'y','',''). ' '. TEXT_TODAY_DATE.' &nbsp;'. TEXT_INT_DATE_NEW; ?></td>
                    </tr>
                    <?php if ($action == 'edit' && !empty($sInfo->contrib_osc_id)) { ?>
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><span style="color:gray;"><?php echo TEXT_INFO_LAST_MODIFIED; ?></span>&nbsp;</td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('contr_last_modified', tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, $sInfo->contr_last_modified, ''), 'disabled') . ' &nbsp; ' . TEXT_LATEST_RELEASE_INFO; ?><?php echo tep_draw_hidden_field('last_modified', $sInfo->contr_last_modified);?></td>
                    </tr>
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><span style="color:gray;"><?php echo TEXT_INFO_STATUS_REFERENCE; ?></span>&nbsp;</td>
                      <td class="dataTableContent"><?php echo tep_draw_input_field('status_reference_date', tep_reformat_strtime(CONTRIB_TRACKER_UPDATE_FORMAT, $sInfo->status_reference_date, ''), 'disabled'); ?> &nbsp; 
					                               <input type="checkbox" name="reset_ref_date_to_current" id="reset_ref" value="y"><label for='reset_ref'><?php echo TEXT_RESET_REF_DATE; ?></label> <?php echo TEXT_RESET_REF_DATE_INFO; ?></td>
                    </tr>
                    <?php } ?>

                    <tr class="dataTableRow">
                      <td valign="top" class="dataTableContent"><?php echo TEXT_CONFIG_COMMENTS; ?>&nbsp;</TD>
                      <td class="dataTableContent"><?php echo tep_draw_textarea_field('config_comments', 'soft', '70', '15', ($sInfo->config_comments)) ; ?></td>
                    </tr>
<?php
if ( $action == 'edit') { 
?>                                        
                    <tr class="dataTableRow">
                      <td class="dataTableContent"><?php echo TEXT_CONFIG_STATUS; ?>&nbsp;</td>
                      <td class="dataTableContent"><?php echo tep_draw_pull_down_menu('status', array(array('id' => '0', 'text' => '0'), array('id' => '1', 'text' => '1'), array('id' => '2', 'text' => '2')), $sInfo->status); ?> &nbsp;&nbsp;&nbsp;
                       0 = <?php echo tep_image(DIR_WS_IMAGES . 'icon_status_red.gif', TEXT_NEW_UPDATE_EXISTS , 10, 10); ?>&nbsp;&nbsp;<?php echo TEXT_NEW_UPDATE_EXISTS; ?>&nbsp;&nbsp;&nbsp;
                       1 = <?php echo tep_image(DIR_WS_IMAGES . 'icon_status_green.gif', TEXT_NO_NEW_UPDATE , 10, 10); ?>&nbsp;&nbsp;<?php echo TEXT_NO_NEW_UPDATE; ?>&nbsp;&nbsp;&nbsp;
                       2 = <?php echo TEXT_NO_STATUS; ?>&nbsp;&nbsp;&nbsp;
                      <?php echo tep_draw_hidden_field('old_status', $sInfo->status);?></td>
                    </tr>
<?php
}
?>          
                    <tr>
                      <td class="main" colspan=2 align="right" valign="top"><br />
                      <?php echo (($form_action == 'insert') ? tep_image_submit('button_insert.gif', IMAGE_INSERT) : tep_image_submit('button_update.gif', IMAGE_UPDATE)) .
                      '&nbsp;&nbsp;&nbsp;<a href="'.tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action'))).'">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL) . '</a>' .
                      '&nbsp;&nbsp;&nbsp;<a href="'.tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params()).'">' . tep_image_button('button_reset.gif', IMAGE_RESET) . '</a>'; ?>
                      </td>
                    </tr>
                  </table>
                </form>
              </td>
            </tr>
<?php
  // end: insert/update form

  } elseif ($action == 'readonly') {
  // start: readonly/details page
      $product_query = tep_db_query("select contr_id, contrib_osc_id, contrib_name, contrib_link, contrib_support, status, config_comments, note_created, contr_last_modified, last_update, status_reference_date from " . TABLE_CONTRIB_TRACKER . " where contr_id = '" . $sID . "'");

      $product = tep_db_fetch_array($product_query);
      $sInfo = new objectInfo($product);
      if ($sInfo->status == '0') $status_desc = TEXT_STATUS_ZERO;
      if ($sInfo->status == '1') $status_desc = TEXT_STATUS_ONE;      
      if ($sInfo->status == '2') $status_desc = TEXT_STATUS_TWO;
?>
            <tr>
              <td colspan="3">
                <br />
                <table border="0" cellspacing="0" cellpadding="2" class="formArea" align="center">
                  <tr class="dataTableHeadingRow">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_OSC_ID; ?>&nbsp;</strong></td>
                    <td class="formAreaTitle"><strong><font color=blue><?php echo $sInfo->contrib_osc_id; ?></font></strong></td>
                  </tr>
                  <tr class="dataTableHeadingRow">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_NAME_VERSION; ?>&nbsp;</strong></td>
                    <td class="formAreaTitle"><strong><font color=blue><?php echo $sInfo->contrib_name; ?></font></strong></td>
                  </tr>
                  <tr class="attributes-odd">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_HTML; ?>&nbsp;</strong></td>
                    <td class="formAreaTitle"><a href="<?php echo $sInfo->contrib_link; ?>" target="_blank" style="text-decoration:none;"><font color=blue><?php echo $sInfo->contrib_link; ?></font></a></td>
                  </tr>
                  <tr class="attributes-even">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_SUPPORT; ?>&nbsp;</strong></td>
                    <td class="formAreaTitle"><a href="<?php echo $sInfo->contrib_support; ?>" target="_blank" style="text-decoration:none;"><font color=blue><?php echo $sInfo->contrib_support; ?></font></a></td>
                  </tr>
                  <tr class="attributes-odd">
                    <td VALIGN="top" class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_CONFIG_COMMENTS; ?>&nbsp;</strong></td>
                    <td class="dataTableContent"><?php echo nl2br($sInfo->config_comments); ?></td>
                  </tr>

                  <tr class="attributes-even">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_DATE_ADDED; ?>&nbsp;</strong></td>
                    <td class="dataTableContent"><?php if ($sInfo->note_created != CONTRIB_TRACKER_MYSQL_EMPTY_DATE) echo $sInfo->note_created; ?></td>
                  </tr>                    
                  <tr class="attributes-odd">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_TO_REMEMBER; ?>&nbsp;</strong></td>
                    <td class="dataTableContent"><?php if ($sInfo->last_update != CONTRIB_TRACKER_MYSQL_EMPTY_DATE) echo $sInfo->last_update; ?></td>
                  </tr>
 
                  <tr class="attributes-even">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_LAST_MODIFIED; ?>&nbsp;</strong></td>
                    <td class="dataTableContent"><?php if ($sInfo->contr_last_modified != CONTRIB_TRACKER_MYSQL_EMPTY_DATE) echo $sInfo->contr_last_modified; ?></td>
                  </tr>                  
                  <tr class="attributes-odd">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_STATUS_REFERENCE; ?>&nbsp;</strong></td>
                    <td class="dataTableContent"><?php if ($sInfo->status_reference_date != CONTRIB_TRACKER_MYSQL_EMPTY_DATE) echo $sInfo->status_reference_date; ?></td>
                  </tr>                  
                  <tr class="attributes-even">
                    <td class="dataTableContent" nowrap="nowrap"><strong><?php echo TEXT_INFO_STATUS; ?>&nbsp;</strong></td>
                    <td class="dataTableContent"><?php echo $sInfo->status . ':&nbsp;' . $status_desc; ?></td>
                  </tr>
                </table>
              </td>
            </tr>
            <tr>
              <td colspan="3" align="center" class="main">
                <br />
                <?php echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID')) . 'sID=' . $sInfo->contr_id, 'NONSSL') . '">' . tep_image_button('button_back.gif', IMAGE_BACK) . '</a>'; ?>

              </td>
            </tr>      
<?php          
  // end: readonly/details page  

  } else {
  // start: Default page
  $columns = 0;
?>
            <tr>
              <td colspan="3">
                <table border="0" width="100%" cellspacing="0" cellpadding="0">
                  <tr>
<!-- TABLE HEADINGS AND SORT ICONS-->
                    <td valign="top">
                      <table border="0" width="100%" cellspacing="0" cellpadding="2">
                        <tr class="dataTableHeadingRow">
                          <td class="dataTableHeadingContent">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=2a" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_up.gif', IMAGE_BUTTON_UPSORT); ?></a><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=2d" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_down.gif', IMAGE_BUTTON_DOWNSORT); ?></a><br /><?php echo TABLE_HEADING_NAME; $columns++; ?></td>
                          <td class="dataTableHeadingContent" align="center"><br /><?php echo TABLE_HEADING_VERSION; $columns++; ?>&nbsp;</td>

                          <?php if ($dadded) { ?><td class="dataTableHeadingContent" align="center"><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=7a" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_up.gif', IMAGE_BUTTON_UPSORT); ?></a><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=7d" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_down.gif', IMAGE_BUTTON_DOWNSORT); ?></a>&nbsp;&nbsp;<br /><?php echo TABLE_HEADING_ADDED; $columns++; ?></td><?php } ?>
                          <?php if ($dcurrent) { ?><td class="dataTableHeadingContent" align="center"><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=5a" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_up.gif', IMAGE_BUTTON_UPSORT); ?></a><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=5d" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_down.gif', IMAGE_BUTTON_DOWNSORT); ?></a>&nbsp;&nbsp;<br /><?php echo TABLE_HEADING_CURRENT; $columns++; ?></td><?php } ?>
                          <?php if ($dlatest) { ?><td class="dataTableHeadingContent" align="center"><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=6a" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_up.gif', IMAGE_BUTTON_UPSORT); ?></a><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=6d" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_down.gif', IMAGE_BUTTON_DOWNSORT); ?></a>&nbsp;&nbsp;<br /><?php echo TABLE_HEADING_LATEST; $columns++; ?></td><?php } ?>

                          <td class="dataTableHeadingContent" align="center"><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=4a" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_up.gif', IMAGE_BUTTON_UPSORT); ?></a><a href="<?php echo FILENAME_CONTRIB_TRACKER . "?sort=4d" . "&amp;" . str_replace('&','&amp;',trim(tep_get_all_get_params(array('action','sort')),'&')); ?>"><?php echo tep_image(DIR_WS_IMAGES . 'icon_down.gif', IMAGE_BUTTON_DOWNSORT); ?></a>&nbsp;&nbsp;<br /><?php echo TABLE_HEADING_STATUS; $columns++; ?></td>
                          <td class="dataTableHeadingContent" align="right"><br /><?php echo TABLE_HEADING_ACTION; $columns++; ?>&nbsp;</td>
                        </tr>
<?php
          switch ($sort) {
              case "2a":
               $order_it_by = "contrib_name, status ";
               break;
              case "2d":
               $order_it_by = "contrib_name DESC, status ";
               break;
              case "4a":
               $order_it_by = "status, contrib_name";
               break;
              case "4d":
               $order_it_by = "status DESC, contrib_name";
               break;
              case "5a":  // Current Installed Contribution version's Date
               $order_it_by = "last_update, contrib_name";
               break;
              case "5d":  // Current Installed Contribution version's Date
               $order_it_by = "last_update DESC, contrib_name";
               break;
              case "6a":  // latest addons.oscommerce.com update Date
               $order_it_by = "contr_last_modified, contrib_name";
               break;
              case "6d":  // latest addons.oscommerce.com update Date
               $order_it_by = "contr_last_modified DESC, contrib_name";
               break;
              case "7a":  // Added to shop date
               $order_it_by = "note_created, contrib_name";
               break;
              case "7d":  // Added to shop date
               $order_it_by = "note_created DESC, contrib_name";
               break;
              default:
			   $sort = "4a";
               $order_it_by = "status, contrib_name";
           }

	// find page number for current selection.
	if ($sID) {
		$count = 0;
		$contrib_query = tep_db_query("select contr_id from " . TABLE_CONTRIB_TRACKER . " order by ".$order_it_by);
		while ($contrib = tep_db_fetch_array($contrib_query)) { $count++; if ($contrib['contr_id'] == $sID) break; }
		$page = ceil($count/$max_display_results);
		tep_db_free_result($contrib_query);
	}

    // IF THIS IS A SEARCH GET THE SEARCH RESULTS FROM THE DB
    if ($search) {
      $admin_query_query_raw = "select * from " . TABLE_CONTRIB_TRACKER . " where contrib_name like '%" . $search . "%' order by " . $order_it_by . " ";
      $admin_query_split = new splitPageResults($page, $max_display_results, $admin_query_query_raw, $admin_query_query_numrows);
      $admin_query_query = tep_db_query($admin_query_query_raw);            
      if (tep_db_num_rows($admin_query_query) == 0) echo '<tr><td  class="dataTableContent" align="left">' . TEXT_NO_DATA . "</td></tr>\n";
    } else {
    // IF THIS IS NOT A SEARCH SO GET ALL THE DATABASE ENTRIES
      $admin_query_query_raw = "select * from " . TABLE_CONTRIB_TRACKER . " order by " . $order_it_by . " ";
      $admin_query_split = new splitPageResults($page, $max_display_results, $admin_query_query_raw, $admin_query_query_numrows);
      $admin_query_query = tep_db_query($admin_query_query_raw);
      if (tep_db_num_rows($admin_query_query) == 0) echo '<tr><td  class="dataTableContent" align="right">' . TEXT_EMPTY_DATABASE . "</td></tr>\n";
    }
    while ($admin_quer = tep_db_fetch_array($admin_query_query)) {
      if ( ((!$sID) || ($sID == $admin_quer['contr_id'])) && (!$sInfo) ) {
        $sInfo_array = array_merge($admin_quer);
        $sInfo = new objectInfo($sInfo_array);
      }

   if ($search == '') {
      if ( (is_object($sInfo)) && ($admin_quer['contr_id'] == $sInfo->contr_id)) {
        echo ' <tr id="defaultSelected" class="dataTableRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="document.location.href=\'' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('sID','action')) . 'sID=' . $admin_quer['contr_id']) . '\'">' . "\n";
      } else {
        echo ' <tr class="dataTableRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="document.location.href=\'' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('sID','action')) . 'sID=' . $admin_quer['contr_id']) . '\'">' . "\n";
      }
   } else {
    $searchresult_query_query_raw = "select contr_id from " . TABLE_CONTRIB_TRACKER . " order by " . $order_it_by . " ";
    $searchresult_query_query = tep_db_query($searchresult_query_query_raw);
    $searchresult_page= round($searchresult_query_query_numrows / $max_display_results)-1;

      // INSERT CONTRIB NAMES INTO PAGE
      if ( (is_object($sInfo)) && ($admin_quer['contr_id'] == $sInfo->contr_id)) {
        echo ' <tr id="defaultSelected" class="dataTableRowSelected" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="document.location.href=\'' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('sID','action')) . 'sID=' . $admin_quer['contr_id']) . '\'">' . "\n";
      } else {
        echo ' <tr class="dataTableRow" onmouseover="rowOverEffect(this)" onmouseout="rowOutEffect(this)" onclick="document.location.href=\'' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('sID','action')) . 'sID=' . $admin_quer['contr_id']) . '\'">' . "\n";
      }
   }
    ?>
                          <td class="dataTableContent">

      <?php
         if ($admin_quer['contrib_link']){
           echo '<a target="_blank" href="' . $admin_quer['contrib_link'] . ($admin_quer['contrib_osc_id']?'#tabs-hist':'') . '" name="' . $admin_quer['contrib_name'] . '">' . $admin_quer['contrib_name'].'</a>';
         }else{
           echo $admin_quer['contrib_name'];
         }
      ?>
                          </td>
                          <td class="dataTableContent" align="center"><?php echo $admin_quer['contrib_vers'];?></td>
                          <?php if ($dadded) { ?><td class="dataTableContent" align="center" nowrap="nowrap"><?php echo tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $admin_quer['note_created'], '' ); ?></td><?php } ?>
                          <?php if ($dcurrent) { ?><td class="dataTableContent" align="center" nowrap="nowrap"><?php echo tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $admin_quer['last_update'], '' ); ?></td><?php } ?>
                          <?php if ($dlatest) { ?><td class="dataTableContent" align="center" nowrap="nowrap"><?php echo tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $admin_quer['contr_last_modified'], '' ); ?></td><?php } ?>
                          
                          
                          <td class="dataTableContent" align="center">
<?php
// SHOW THE STATUS ICONS
	  // show red
      if ($admin_quer['status'] == '0') {
        echo tep_image(DIR_WS_IMAGES . 'icon_status_red.gif', TEXT_NEW_UPDATE_EXISTS, 10, 10) . '&nbsp;';
      } else { 
        echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')) . 'action=setflag&amp;flag=0&amp;id=' . $admin_quer['contr_id'] . '&amp;set_date=' . (empty($admin_quer['contrib_osc_id']) ? '' : urlencode($admin_quer['last_update'])), 'NONSSL') . '">' . tep_image(DIR_WS_IMAGES . 'icon_status_red_light.gif', TEXT_SET_NEW_UPDATE_EXISTS, 10, 10) . '</a>&nbsp;'; 
      }
	  // show green
      if ($admin_quer['status'] == '1') {
        echo tep_image(DIR_WS_IMAGES . 'icon_status_green.gif', TEXT_NO_NEW_UPDATE, 10, 10);
      } else {
        echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')) . 'action=setflag&amp;flag=1&amp;id=' . $admin_quer['contr_id'] . '&amp;set_date=' . (empty($admin_quer['contrib_osc_id']) ? '' : urlencode($admin_quer['contr_last_modified'])), 'NONSSL') . '">' . tep_image(DIR_WS_IMAGES . 'icon_status_green_light.gif', TEXT_SET_NO_NEW_UPDATE, 10, 10) . '</a>';
      }
?>
                          </td>
                          <td class="dataTableContent" align="right">
<?php 
// INSERT THE ACTION ICONS
	  if ($admin_quer['contrib_support']) {
		$support_url = $admin_quer['contrib_support'];
		if (strpos($admin_quer['contrib_support'], CONTRIB_TRACKER_SUPPORT_URL) !== false) {
		  $support_url = $admin_quer['contrib_support'] . '&amp;view=getlastpost';
		}
		echo '<a target="_blank" href="' .  $support_url . '">' .tep_image(DIR_WS_IMAGES . 'icon_help.gif', TEXT_OSC_SUPPORT_THREAD) . '</a>&nbsp;&nbsp;'; 
	  } else {
		// add blank spacer in place of no contrib support link
		echo tep_image(DIR_WS_IMAGES . 'pixel_trans.gif', '', '14', '14') . '&nbsp;&nbsp;';
	  }

	  if ($admin_quer['contrib_osc_id']){
		echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action','sID')) . 'action=manualcheck&amp;oscID=' . $admin_quer['contrib_osc_id'].'&amp;sID=' . $admin_quer['contr_id']) . '">' . tep_image(DIR_WS_IMAGES . 'icon_manual_check.jpg', TEXT_MANUAL_CHECK) . '</a>&nbsp;&nbsp;'; 
	  } else {
		// add blank spacer in place of no contrib check link
		echo tep_image(DIR_WS_IMAGES . 'pixel_trans.gif', '', '14', '14') . '&nbsp;&nbsp;';
	  }

	  if (htmlspecialchars($search) == '') {
		$reference = 'page';
	  } else {
		$reference = 'search';
	  }
	  
	  if ( (is_object($sInfo)) && ($admin_quer['contr_id'] == $sInfo->contr_id) ) {
		echo tep_image(DIR_WS_IMAGES . 'icon_arrow_right.gif', '');
	  } else {
		echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID')) . 'sID=' . $admin_quer['contr_id']) . '">' .tep_image(DIR_WS_IMAGES . 'icon_info.gif', TEXT_INFO) . '</a>'; 
	  }

?>
                          </td>
                        </tr>
<?php
    }
?>
                        <tr>
                          <td colspan="<?php echo $columns; ?>">
                            <table border="0" width="100%" cellpadding="0"cellspacing="2">
                              <tr>
                                <td class="smallText" valign="top"><?php echo $admin_query_split->display_count($admin_query_query_numrows, $max_display_results, $page, TEXT_DISPLAY_NUMBER_OF_RECORDS); ?></td>
                                <td class="smallText" align="right"><?php echo $admin_query_split->display_links($admin_query_query_numrows, $max_display_results, MAX_DISPLAY_PAGE_LINKS, $page, 'sort=' . $sort); ?></td>
                              </tr>
                   <?php
                      if (!$action) {
                    ?>
                              <tr> 
                                <td class="smallText" align="center"><?php
                                  echo tep_draw_form('cols', FILENAME_CONTRIB_TRACKER, '', 'get');
								  echo tep_get_all_get_params_as_hidden(array('action','dadded','dcurrent','dlatest'));
                                  ?>Date Columns: <input type="checkbox" name="dadded" id="dadded_id" value="y" <?php echo ($dadded?'checked="checked"':''); ?> onChange="this.form.submit();"><label for='dadded_id'>Added</label>
                                  <input type="checkbox" name="dcurrent" id="dcurrent_id" value="y" <?php echo ($dcurrent?'checked="checked"':''); ?> onChange="this.form.submit();"><label for='dcurrent_id'>Current</label>
                                  <input type="checkbox" name="dlatest" id="dlatest_id" value="y" <?php echo ($dlatest?'checked="checked"':''); ?> onChange="this.form.submit();"><label for='dlatest_id'>Latest</label>
                                  </form>
                                </td>
                                <td class="smallText" align="right">
                                  <?php echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')) . 'action=manualcheckall') . '">' . tep_image_button('button_check_all.gif', IMAGE_CHECKALL) . '</a>'; ?>
                                  <?php echo '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, 'action=new') . '">' . tep_image_button('button_insert.gif', IMAGE_INSERT) . '</a>'; ?>
                                </td>
                              </tr>

<!-- // INSERT THE HELP NOTES -->
                              <tr> 
                                <td class="smallText" colspan="2" align="left">
                                  <?php echo '<br /><strong>'. TEXT_HELP_NOTES_HEADER . '</strong><br /><ul>' . TEXT_HELP_NOTES . '</ul><br />'; ?>
                                </td>
                              </tr>
                              <tr>
<!-- // INSERT NEWEST CONTRIBS FROM RSS -->
                                <td class="smallText" colspan="2" align="left"><?php 
                                  echo tep_draw_form('rssfeed', FILENAME_CONTRIB_TRACKER, '', 'get');
								  echo tep_get_all_get_params_as_hidden(array('action','showrss'));
								 ?><strong><?php echo TEXT_CONTRIB_HEADER; ?></strong> &nbsp; &nbsp; &nbsp; <input type="checkbox" name="showrss" id="showrss_id" value="y" <?php echo ($showrss?'checked="checked"':''); ?> onChange="this.form.submit();"><label for='showrss_id'>Update from RSS feed now</label></form><br />
<?php
if ($showrss) {
	if (is_array($articlelist)) {
	  echo "<ol>\n";
	  if ( is_array($articlelist['item']) ) {
		  foreach ($articlelist['item'] as $article ) {
			$thelink = $article['link'];
			$thetitle = $article['title'];
			echo "<li><a href=\"" . $thelink . "\" target=\"_blank\">" . $thetitle . "</a></li>\n";
		  }
	  }
	  echo "</ol>\n";
	} else {
	  echo "ERROR: Could not open RDF feed\n";
	} 
} 
?>
                                </td>
                              </tr>
<?php
  } 
?>  
                            </table>
                          </td>
                        </tr>
                      </table>
                    </td>
<?php

  $heading = array();
  $contents = array();

// RIGHT COLUMN STUFF
  switch ($action) {
    case 'delete':
      $heading[] = array('text' => '<center><strong>' . TEXT_INFO_HEADING_DELETE . '</strong></center>');
      $contents = array('form' => tep_draw_form('install_contr_del', FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')) . 'action=deleteconfirm'));
      $contents[] = array('text' => TEXT_INFO_DELETE_INTRO);
      $contents[] = array('text' => '<br /><strong>' . $sInfo-> contrib_name . '</strong>');
      $contents[] = array('align' => 'center', 'text' => '<br />' . tep_image_submit('button_delete.gif', IMAGE_CONFIRM_DELETE) .
                                                         '&nbsp; <a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action')) . 'sID=' . $sInfo->contr_id) . '">' . tep_image_button('button_cancel.gif', IMAGE_CANCEL)  . '</a>' . '<br /><br />');
      break;
    default:
      if (is_object($sInfo)) {
        $heading[] = array('text' => '<center><strong>' . $sInfo->contrib_name . '</strong></center>');
        $contents[] = array('align' => 'center', 'text' => '<strong>'. TEXT_VERSION_NUMBER .'</strong> ' . $sInfo->contrib_vers);
        $contents[] = array('align' => 'center', 'text' => '<strong>'. TEXT_CONTRIBUTION_ID .'</strong> ' . $sInfo->contrib_osc_id);
        $contents[] = array('text' => '<br /><strong>' . TEXT_INFO_DATE_ADDED . '</strong><br /> ' . tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $sInfo->note_created, 'none') );
        $contents[] = array('text' => '<br /><strong>' . TEXT_INFO_TO_REMEMBER . '</strong><br /> ' . tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $sInfo->last_update, 'none') );
        $contents[] = array('text' => '<span style="color:'.(strtotime($sInfo->status_reference_date)<strtotime($sInfo->contr_last_modified) ? '#922' : '#262' ).';"><strong>' . TEXT_INFO_LAST_MODIFIED . '</strong><br /> ' . tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $sInfo->contr_last_modified, 'none') . '</span>' );
        $contents[] = array('text' => '<span style="color:'.(strtotime($sInfo->status_reference_date)<strtotime($sInfo->contr_last_modified) ? '#922' : '#262' ).';"><strong>' . TEXT_INFO_STATUS_REFERENCE . '</strong><br /> ' . tep_reformat_strtime(CONTRIB_TRACKER_DISPLAY_FORMAT, $sInfo->status_reference_date, 'none') . '</span>' );
        if (!empty($sInfo->contrib_link)) { $contents[] = array('text' => '<br /><strong>'. TEXT_LINK_TO .'</strong> <a target="_blank" href="' . $sInfo->contrib_link . ($sInfo->contrib_osc_id?'#tabs-hist':'') . '">' . TEXT_CONTRIBUTION_LINK . '</a>'); } 
        if (!empty($sInfo->contrib_support)) { $contents[] = array('text' => (empty($sInfo->contrib_link)?'<br />':'') . '<strong>'. TEXT_LINK_TO .'</strong> <a target="_blank" href="' . $sInfo->contrib_support . ((strpos($sInfo->contrib_support, CONTRIB_TRACKER_SUPPORT_URL) !== false)?'&amp;view=getlastpost':'') . '">'  . TEXT_SUPPORT_LINK . '</a>'); }
        $contents[] = array('text' => '<br /><strong>' . TEXT_CONFIG_COMMENTS .'</strong> ' . nl2br($sInfo->config_comments) . '<br /><br />');
        $contents[] = array('align' => 'center', 'text' => '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID')) . 'sID=' . $sInfo->contr_id . '&amp;action=edit') . '">' . tep_image_button('button_edit.gif', IMAGE_EDIT) . '</a>' . ' &nbsp; ' . '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID')) . 'sID=' . $sInfo->contr_id . '&amp;action=delete') . '">' . tep_image_button('button_delete.gif', IMAGE_DELETE) . '</a>' .
                                                           '<br /><br />' . '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action', 'sID')) . 'sID=' . $sInfo->contr_id . '&amp;action=readonly') . '">' . tep_image_button('button_details.gif', IMAGE_DETAILS) . '</a>' . ($sInfo->contrib_osc_id ? ' &nbsp; ' . '<a href="' . tep_href_link(FILENAME_CONTRIB_TRACKER, tep_get_all_get_params(array('action','sID')) . 'action=manualcheck&amp;oscID=' . $sInfo->contrib_osc_id.'&amp;sID=' . $sInfo->contr_id) . '">' . tep_image_button('button_check_for_update.gif', IMAGE_CHECK_FOR_UPDATE) . '</a>' : '') . '<br /><br />');
      } else {
        $heading[] = array('text' => '<center><strong>' . TEXT_SELECTED_ITEM_NOT_ON_PAGE . '</strong></center>');
        $contents[] = array('text' => '<p>&nbsp;</p>');
	  }
      break;
  }
  if ( (tep_not_null($heading)) && (tep_not_null($contents)) ) {
    echo '            <td width="25%" valign="top" align="center">' . "\n";
    $box = new box;
    echo $box->infoBox($heading, $contents);
	echo '<br />' . $conf->db_configurer_button();
    echo '            </td>' . "\n";
  } ?>

                  </tr>
                </table>
              </td>
            </tr>

<?php
  // end: Default page
  }
?>

          </table></td>
      </tr>
    </table></td>
<!-- body_text_eof //-->
  </tr>
</table>
<!-- body_eof //-->

<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
<br>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
