<?php
/*
  $Id: contrib_tracker.php,v 1.8.0 2014/07/07 00:00:00 $

  Designed for: osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Released under the GNU General Public License
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


// reformat a time string
function tep_reformat_strtime($format, $time, $return = CONTRIB_TRACKER_MYSQL_EMPTY_DATE) {
  if ($time != CONTRIB_TRACKER_MYSQL_EMPTY_DATE && $time != '') {
	return strftime($format, strtotime($time));
  }
  
  return $return;
}

// use curl to pull in web page
function tep_curl_fetch($OSCURL) {
  if (extension_loaded('curl')) {
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_HEADER, 0);
	curl_setopt($ch, CURLOPT_URL, $OSCURL) ;
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	$data = curl_exec($ch);
	curl_close($ch); 
	return $data;
  }
  
  return false;
}

//Function to parse the RDF feed
//Does not rely on PHP XML parser due to issues.
if (!function_exists("parse_xml")) {
	function parse_xml($text) {
	  $reg_exp = '/<(\w+)[^>]*>(.*?)<\/\\1>/s';
	  preg_match_all($reg_exp, $text, $match);
	  foreach ($match[1] as $key=>$val) {
		if ( preg_match($reg_exp, $match[2][$key]) ) {
			$array[$val][] = parse_xml($match[2][$key]);
		} else {
			if ( preg_match('/<!\[CDATA\[(.*?)\]\]>/s',$match[2][$key], $string) ) {
				$array[$val] = $string[1];
			} else {
				$array[$val] = $match[2][$key];
			}
		}
	  }
	  return $array;
	} 
} 

// get contents of file into a string
// For compatibility with PHP4 < 4.3.0
if (!function_exists("file_get_contents")) {
	function file_get_contents($f) {
	  $h = @fopen($f, 'rb'); //rss cached file path
	  if ($h) {
		$data = '';
		while (!feof($h)) {
		  $d .= fread($h, 8192);
		}
		fclose($h);
	  } else {
		$d = $false;
	  }
	  return $d;
	}
}

// THIS GETS THE FEED AND PARSES IT
function tep_process_oscommerce_rss_feed() {
	$data = @file_get_contents(CONTRIB_TRACKER_XML_URL);
	
	if (!$data && (extension_loaded('curl') == 1)) {
	  $data = tep_curl_fetch(CONTRIB_TRACKER_XML_URL);
	}
	
	if (!strncmp($data,"<?xml",5)) {
	  $response = parse_xml($data);
	
	  $articlelist = $response['rss'][0]['channel'][0];
	  if ( is_array($articlelist['item']) ) {
		  foreach ($articlelist['item'] as $article ) {
			$thelink = $article['link'];
			$thetitle = $article['title'];
			$osc_rss_pubdate_raw = $article['pubDate'];
			$osc_rss_pubdate = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, $osc_rss_pubdate_raw);
		
		// add backslashes to characters that need escaping
			$thetitle = addslashes($thetitle);
		
		// UPDATE THE CONTRIBUTIONS THAT ARE IN THE RSS FILE
			tep_db_query("UPDATE " . TABLE_CONTRIB_TRACKER . " SET status ='0', contr_last_modified = '" . $osc_rss_pubdate . "' where contrib_name = '" . $thetitle . "' and status_reference_date < '" . $osc_rss_pubdate . "'");
		  }
	  }
	  return $articlelist;
	}

	return false;
}

function tep_set_contrib_query_status($contr_id, $status, $set_date) {
  switch ($status) {
    case '0':
      return tep_db_query("update " . TABLE_CONTRIB_TRACKER . " set status = '0'" . (!empty($set_date) ? ", status_reference_date='" . tep_db_input($set_date) . "'" : '') . " where contr_id = '" . tep_db_input($contr_id) . "'");
      break;
	case '1':
      return tep_db_query("update " . TABLE_CONTRIB_TRACKER . " set status = '1'" . (!empty($set_date) ? ", status_reference_date='" . tep_db_input($set_date) . "'" : '') . " where contr_id = '" . tep_db_input($contr_id) . "'");
      break;
    case '2':
      return tep_db_query("update " . TABLE_CONTRIB_TRACKER . " set status = '2' where contr_id = '" . tep_db_input($contr_id) . "'");
  }

  return false;
}

// pull contrib information from addons.oscommerce.com
function contrib_check($contrib_id) {
  $contrib_info = array();
  $matches = array();
  $matches2 = array();
  $matches3 = array();
  
  if(!empty($contrib_id)){
    if ($var = tep_curl_fetch(CONTRIB_TRACKER_CONTRIBS_URL . (int)$contrib_id)) {
		// look for latest contribution date
		preg_match_all('/[0-9]+ [A-Za-z]{3} *[0-9]{4}/', $var, $matches) ;
		if ($matches[0]){
		  $contrib_info['last_osc_update'] = tep_reformat_strtime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, $matches[0][0]);
		}
		
		// look for contribution name
		preg_match('/<h2>.*<\/a>/i', $var, $matches2);
		$contrib_info['contrib_name'] = str_replace('<br />', ' ', strip_tags($matches2[0], "<br />")) ;
	
		// look for old style support topic link
		preg_match('/\Qshowtopic=\E([0-9]*)/', $var, $matches3);
		if ($matches3[1]) {
		  $contrib_info['contrib_support_topic'] = $matches3[1];
		} else {
		  // look for new style support topic link if old style not found
		  preg_match('#/topic/([0-9]*)#', $var, $matches3);
		  if ($matches3[1]) {
		     $contrib_info['contrib_support_topic'] = $matches3[1];
		  }
		}
	    return $contrib_info;	
    }
  }
	
  return false;	
}

//convert old links to new ones
function old_to_new_url($URL){
  global $messageStack;
  
  if (strpos($URL, CONTRIB_TRACKER_OLD_CONTRIBS_URL)) {
    $messageStack->add_session(MESSAGE_LINKCHANGE_SUCCESS, 'success');
    return str_replace(CONTRIB_TRACKER_OLD_CONTRIBS_URL, CONTRIB_TRACKER_CONTRIBS_URL, $URL);
  }
  return $URL;
}

//get the contrib id from the url
//only get id from oscommerce urls
function get_contrib_id($URL) {
  if (!empty($URL)) {
    $pos = strpos($URL, CONTRIB_TRACKER_CONTRIBS_URL);

    if ($pos !== false){
      $contrib_id = (int)substr($URL, strrpos($URL , '/') +1);
    }
    if (is_numeric($contrib_id)) {
	  return $contrib_id; 
    }
  }
  
  return false;
}

// return all $_get as hidden fields for a form
function tep_get_all_get_params_as_hidden($excepts) {
  $return = '';
  $get_params = trim(tep_get_all_get_params($excepts),'&');
  $get_params_array = explode('&',$get_params);
  foreach ($get_params_array as $getpair) {
	  $getvar = explode('=',$getpair);
	  $return .= tep_draw_hidden_field($getvar[0],$getvar[1]);
  }
  return $return;
}

?>