<?php
/*
  $Id: contrib_tracker.php,v 1.7.18 2009/09/06 17:33:32 SteveDallas Exp $
  
  Designed for: osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Released under the GNU General Public License
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/* ///////////////////////////////////////////////////////
 * Notes on Using Dates in this contribution
 * ///////////////////////////////////////////////////////
 * 
 * 'note_created' -- Date Added to Store 
 *    DESCRIPTION: This field is used for the date the current contribution was added to the store.
 *    USAGE: This data field is exclusively maintained and updated by the user for their reference.
 * 
 * 'last_update' -- Current Installed Version Date (formerly: Last integrated into store)
 *    DESCRIPTION: This field is used as the date of the Last, or Current, contribution date 
 *                 currently installed in the shop.
 *    USAGE: This data field is exclusively maintained and updated by the user for their reference.
 * 
 * 'contr_last_modified' -- Lastest at addons.oscommerce.com (formerly: Last official update)
 *    DESCRIPTION: This field is used by the code to maintain the date of the latest uploaded 
 *                 version at addons.oscommerce.com
 *    USAGE: This data field is exclusively maintained and updated by the code, and should always 
 *           reflect the date of the latest upload at addons.oscommerce.com
 * 
 * 'status_reference_date' -- Status Reference Date
 *    DESCRIPTION: This field is used by the code to compare to the dates retrieved from the 
 *                 contribution page at addons.oscommerce.com and the RSS feed.  This data field is
 *                 manipulated to allow the user to decide whether the latest official update at
 *                 addons.oscommerce.com is useful to their installation. If a new official release is 
 *                 detected, the user can reset the display to indicate the contribution is up-to-date. 
 *                 The code changes this field to the latest official release date for future comparison. 
 *                 Maintaining this "reference date" allows all the other dates to always reflect their intended uses.
 *    USAGE: - This data field is manipulated by the code. 
 *           - When a contribution is added, this field is set to the 'last_update' entered by the user 
 *             and the entry has a contribution ID entered by the user.
 *           - The user has the ability to reset this field to the 'last_update' date in the edit page.
 *           - If an update check determines a new release exists by comparing the new date to this one, 
 *             the status is changed to red (0) (update is available).
 *           - If the user determines the new release is not applicable to their installation, they click the 
 *             green status icon and this date is set to the latest release date from 'contr_last_modified' 
 *             and the status is reset to green (1). If they later decide to return the status to red (0),
 *             clicking the red status icon will set this field to the 'last_update' date.
 * 
 * ////////////////////////////////////////////////////// */


//
//
// initializations & constants
// //////////////////////////////////////////////////////////////////

// Language
define ('CONTRIB_TRACKER_NAME', 'Contribution Tracker');
define ('CONTRIB_TRACKER_ERROR', 'Contribution Tracker Error');
define ('CONTRIB_TRACKER_SUMMARY', 'Contribution Tracker Summary');
define ('CONTRIB_TRACKER_ARTICLE_MSG', '%s contributions listed in the feedburner.com RSS feed.');
define ('CONTRIB_TRACKER_UPDATE_MSG', 'The check is complete. The following %s contribution(s) need updating.');
define ('CONTRIB_TRACKER_SUCCESS', 'Success!');

// If true, send the feed to admin if we can't find any articles in the RSS file
define ('CONTRIB_TRACKER_DEBUG_MODE', false);

// web URL constant
define ('CONTRIB_TRACKER_XML_URL', 'http://feedproxy.feedburner.com/osCommerce_Contributions');
// CONTRIB_TRACKER_MYSQL_DATE_FORMAT is the date format MySQL stores and understands as a valid date
define ('CONTRIB_TRACKER_MYSQL_DATE_FORMAT','%Y-%m-%d %H:%M:%S');

// set default timezone if none exists (PHP 5.3 throws an E_WARNING)
if (version_compare(PHP_VERSION, '5.2', '>=') && !ini_get('date.timezone')) {
  date_default_timezone_set('America/New_York');
}

// Determine whether we're running from a shell
if (isset($_ENV["SHELL"])) {
  $silent = true;
} else {
  $silent = false;
}


//
//
// osCommerce startup includes & requires
// //////////////////////////////////////////////////////////////////

// include server parameters
if (file_exists('includes/local/configure.php')) { // for developers
	include('includes/local/configure.php');
} else {
	include('includes/configure.php');
}

// include the list of project database tables
  require(DIR_WS_INCLUDES . 'database_tables.php');

// include the database functions
  require(DIR_WS_FUNCTIONS . 'database.php');

// make a connection to the database... now
  tep_db_connect() or die('Unable to connect to database server!');

// set the application parameters
  $configuration_query = tep_db_query('select configuration_key as cfgKey, configuration_value as cfgValue from ' . TABLE_CONFIGURATION);
  while ($configuration = tep_db_fetch_array($configuration_query)) {
    define($configuration['cfgKey'], $configuration['cfgValue']);
  }

// define general functions used application-wide
  require(DIR_WS_FUNCTIONS . 'general.php');

// include the mail classes
  require(DIR_WS_CLASSES . 'mime.php');
  require(DIR_WS_CLASSES . 'email.php');

// include validation functions (right now only email address)
  require(DIR_WS_FUNCTIONS . 'validations.php');

// set the language
  include(DIR_WS_CLASSES . 'language.php');
  $lng = new language();

  if (isset($HTTP_GET_VARS['language']) && tep_not_null($HTTP_GET_VARS['language'])) {
    $lng->set_language($HTTP_GET_VARS['language']);
  } else {
    $lng->get_browser_language();
  }

  $language = $lng->language['directory'];
  $languages_id = $lng->language['id'];

// include the language translations
  require(DIR_WS_LANGUAGES . $language . '.php');

// Install a configuration key to determine whether to send email reports to store owner.  
// Set it to 'false'. (Can be changed in admin Config->E-Mail.)
if (CONTRIB_TRACKER_NOTIFICATION == 'CONTRIB_TRACKER_NOTIFICATION') {
  tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) values ('Contrib Tracker Notification email', 'CONTRIB_TRACKER_NOTIFICATION', 'false', 'Send Contrib Tracker notifications to store owner', '12', '4815', now(), 'tep_cfg_select_option(array(\'true\', \'false\'),')");   
}


//
//
// functions
// //////////////////////////////////////////////////////////////////

  //Function to parse the RSS feed
  //Does not rely on PHP XML parser due to issues.
  function parse_xml($text) {
      $reg_exp = '/<(\w+)[^>]*>(.*?)<\/\\1>/s';
      preg_match_all($reg_exp, $text, $match);
      foreach ($match[1] as $key=>$val) {
        if ( preg_match($reg_exp, $match[2][$key]) ) {
            $array[$val][] = parse_xml($match[2][$key]);
        } else {
		    if ( preg_match('/<!\[CDATA\[(.*?)\]\]>/s',$match[2][$key], $string) ) {
			    $array[$val] = $string[1];
			} else {
                $array[$val] = $match[2][$key];
			}
        }
      }
      return $array;
  } 

  //get contents of file into a string
  //For compatibility with PHP4 < 4.3.0
  if (!function_exists('file_get_contents')) {
    function file_get_contents($f) {
      $h = @fopen($f, 'rb'); //rss cached file path
      if ($h) {
        $data = '';
        while (!feof($h)) {
          $d .= fread($h, 8192);
	    }
        fclose($h);
      } else {
        $d = $false;
      }
	  return $d;
	}
  }

  // Decode HTML special characters (for PHP<5.1.0)
  if (!function_exists('htmlspecialchars_decode')) {
    function htmlspecialchars_decode($string, $style=ENT_COMPAT)
    {
        $translation = array_flip(get_html_translation_table(HTML_SPECIALCHARS, $style));
        if($style === ENT_QUOTES){ $translation['&#039;'] = '\''; }
        return strtr($string,$translation);
    }
  }


  // Grab a file using cURL
  function curl_get_osc_contents($OSCURL) {
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_HEADER, 0);
	curl_setopt($ch, CURLOPT_URL, $OSCURL) ;
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	$data = curl_exec($ch);
	curl_close($ch); 
	return $data ;
  }
  
  // function doesn't exist in osCommerce v2.2ms2
  if (!function_exists('tep_db_affected_rows')) {
    function tep_db_affected_rows($link = 'db_link') {
      global $$link;

	  $inf = @mysqli_get_server_info($$link);
	  if (!empty($inf)) {
        return mysqli_affected_rows($$link);
	  } else {
        return mysql_affected_rows($$link);
	  }
    }
  }
  
  // dummy function definitions to keep language file from complaining
  function tep_session_save_path() {
    $s = '';
    return $s;
  }
  
  function tep_href_link($s) {
    $s = '';
    return $s;
  }


//
//
// let's get started
// //////////////////////////////////////////////////////////////////

// Make the output minimal valid HTML
if (!$silent) {
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
    <title><?php echo TITLE; ?></title>
  </head>
  <body>
<?php
}

// try using fopen (fopen wrappers may not be enabled on all servers due to security)
$data = @file_get_contents(CONTRIB_TRACKER_XML_URL);

// falback on curl if fopen fails
if (!$data && (extension_loaded('curl') == 1)) {
  $data = curl_get_osc_contents(CONTRIB_TRACKER_XML_URL);
}

//Initialize counters
$articlecount = 0;
$updated = 0;
$updatedlist = '';
$report = '';

if ($data) {
  $response = parse_xml($data);

  $articlelist = $response['rss'][0]['channel'][0];
  if (is_array($articlelist['item'])) {
    foreach ($articlelist['item'] as $article ) {
      $articlecount++;
      $osc_rss_pubdate = strtotime($article['pubDate']);
      $osc_rss_pubdate = strftime(CONTRIB_TRACKER_MYSQL_DATE_FORMAT, $osc_rss_pubdate);

// UPDATE THE CONTRIBUTIONS THAT ARE IN THE RSS FILE
	  //Always contr_last_modified synced with contribs, keep update latest update date regardless.
      tep_db_query("UPDATE " . TABLE_CONTRIB_TRACKER . " SET contr_last_modified = '" . $osc_rss_pubdate . "' where contrib_link = '" . $article['link'] . "'");
	  //Update status when osCommerce Addon date is status_reference_date less than addon's date.
      tep_db_query("UPDATE " . TABLE_CONTRIB_TRACKER . " SET status ='0' where contrib_link = '" . $article['link'] . "' and status_reference_date < '" . $osc_rss_pubdate . "'");
      if (tep_db_affected_rows()) {
	    $updated++;
	    $updatedlist .= '<strong>' . $article['title'] . '</strong>' . "\n";  // html tags are stripped before emailing
	    $updatedlist .= '<a href="'.$article['link'].'" style="text-decoration:none;">' . $article['link'] . '</a>' . "\n";  // html tags are stripped before emailing
        $updatedlist .= htmlspecialchars_decode($article['description']) . "\n - - - - - - - -\n\n";
	  }
    }
  } else {
    $report = print_r($data, true); // create report regardless of email reporting status so it can be used in realtime mode.
	// There was a problem with the feed.  Send it to the store owner.
    if (tep_validate_email(STORE_OWNER_EMAIL_ADDRESS) && CONTRIB_TRACKER_DEBUG_MODE) {
      $name = CONTRIB_TRACKER_NAME;
      $subject = CONTRIB_TRACKER_ERROR;
      if (tep_validate_email(STORE_OWNER_EMAIL_ADDRESS)) {
        tep_mail(STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, $subject, strip_tags($report), $name, STORE_OWNER_EMAIL_ADDRESS);
      }
    }   
  }
}

//send an email if any contribs need updating.
if ($updated > 0 && CONTRIB_TRACKER_NOTIFICATION == 'true') {
  $error = false;
  $name = CONTRIB_TRACKER_NAME;
  $subject = CONTRIB_TRACKER_SUMMARY;
  $enquiry = sprintf(CONTRIB_TRACKER_ARTICLE_MSG, $articlecount) . "\n" . sprintf(CONTRIB_TRACKER_UPDATE_MSG, $updated) . "\n\n" . strip_tags($updatedlist);
  if (tep_validate_email(STORE_OWNER_EMAIL_ADDRESS)) {
    tep_mail(STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, $subject, $enquiry, $name, STORE_OWNER_EMAIL_ADDRESS);
  }
}

if (!$silent) { 
	if (empty($report)) {
		echo '<br />' . CONTRIB_TRACKER_SUCCESS . '<br />' . "\n"; 
		echo sprintf(CONTRIB_TRACKER_ARTICLE_MSG, $articlecount) . '<br /><br />'; 
		if ($updated > 0) {
			echo sprintf(CONTRIB_TRACKER_UPDATE_MSG, $updated) . '<br /><br />' . "\n" . str_replace('<br /><br />','<br />',nl2br($updatedlist));
		}
	} else {
		echo CONTRIB_TRACKER_ERROR . '<br /><br />' . "\n";
		echo $report;
	}
?>
  </body>
</html>
<?php
}
?>
